@@ -157,7 +157,7 @@ class IdentityV3RbacPolicyAssociationTests(rbac_base.IdentityV3RbacBaseTests,
         This test must check
           * whether the persona can delete a policy association for a region
             and service
-        """
+        """  # noqa: E501
         pass
 
 
@@ -444,7 +444,12 @@ class DomainAdminTests(SystemReaderTests, base.BaseIdentityTest):
             policy_id=self.policy_id)
 
 
-class DomainMemberTests(DomainAdminTests, base.BaseIdentityTest):
+class DomainManagerTests(DomainAdminTests, base.BaseIdentityTest):
+
+    credentials = ['domain_manager', 'system_admin']
+
+
+class DomainMemberTests(DomainManagerTests):
 
     credentials = ['domain_member', 'system_admin']
 
@@ -459,7 +464,12 @@ class ProjectAdminTests(SystemAdminTests):
     credentials = ['project_admin', 'system_admin']
 
 
-class ProjectMemberTests(DomainReaderTests):
+class ProjectManagerTests(DomainReaderTests):
+
+    credentials = ['project_manager', 'system_admin']
+
+
+class ProjectMemberTests(ProjectManagerTests):
 
     credentials = ['project_member', 'system_admin']
 
